@@ -141,13 +141,51 @@ class MutationDefinition:
                 result = await db.execute_function(full_function_name, input_data)
 
             # Parse result into Success or Error type
-            return parse_mutation_result(
+            parsed_result = parse_mutation_result(
                 result,
                 self.success_type,
                 self.error_type,
                 self.error_config,
             )
 
+            # Return the parsed result directly - let GraphQL handle object resolution
+            # Serialization will be handled at the JSON encoding stage
+
+            # DEBUG: Check if errors field is being set correctly for enterprise compatibility
+            if hasattr(parsed_result, "errors") and hasattr(parsed_result, "__class__"):
+                class_name = parsed_result.__class__.__name__
+                errors_value = parsed_result.errors
+                import logging
+
+                logger = logging.getLogger(__name__)
+                logger.info(f"Mutation result: {class_name}, errors={errors_value}")
+
+                # CRITICAL FIX: Force populate errors for frontend compatibility
+                if class_name.endswith("Error") and errors_value is None:
+                    status = getattr(parsed_result, "status", "unknown")
+                    message = getattr(parsed_result, "message", "Unknown error")
+
+                    # Create error from status and message
+                    if ":" in status:
+                        error_code = 422
+                        identifier = status.split(":", 1)[1]
+                    else:
+                        error_code = 500
+                        identifier = "general_error"
+
+                    error_obj = {
+                        "code": error_code,
+                        "identifier": identifier,
+                        "message": message,
+                        "details": {},
+                    }
+
+                    # Force set errors array
+                    parsed_result.errors = [error_obj]
+                    logger.info(f"FORCED errors population: {[error_obj]}")
+
+            return parsed_result
+
         # Set metadata for GraphQL introspection
         resolver.__name__ = to_snake_case(self.name)
         resolver.__doc__ = self.mutation_class.__doc__ or f"Mutation for {self.name}"
